@@ -130,23 +130,9 @@ def get_calculated_config(args, config_manager):
     if args.hash:
         col_list = None if args.hash == "*" else cli_tools.get_arg_list(args.hash)
         fields = config_manager._build_dependent_aliases("hash", col_list)
-        aliases = [field["name"] for field in fields]
-        # config_manager.append_dependent_aliases(aliases)
-        # Add to list of necessary columns for selective hashing in order to drop
-        # excess columns with invalid data types (i.e structs) when generating source/target DFs
-        if col_list:
-            config_manager.append_dependent_aliases(col_list)
-            config_manager.append_dependent_aliases(aliases)
     elif args.concat:
         col_list = None if args.concat == "*" else cli_tools.get_arg_list(args.concat)
         fields = config_manager._build_dependent_aliases("concat", col_list)
-        aliases = [field["name"] for field in fields]
-        # config_manager.append_dependent_aliases(aliases)
-        # Add to list of necessary columns for selective concatenation in order to drop
-        # excess columns with invalid data types (i.e structs) when generating source/target DFs
-        if col_list:
-            config_manager.append_dependent_aliases(col_list)
-            config_manager.append_dependent_aliases(aliases)
 
     if len(fields) > 0:
         max_depth = max([x["depth"] for x in fields])
@@ -183,6 +169,24 @@ def build_config_from_args(args, config_manager):
     Args:
         config_manager (ConfigManager): Validation config manager instance.
     """
+
+    if config_manager.validation_type == consts.CUSTOM_QUERY:
+        config_manager.append_custom_query_type(args.custom_query_type)
+
+        source_query_str = config_manager.get_query_from_file(args.source_query_file)
+        config_manager.append_source_query(source_query_str)
+
+        target_query_str = config_manager.get_query_from_file(args.target_query_file)
+        config_manager.append_target_query(target_query_str)
+
+        if args.custom_query_type == consts.COLUMN_VALIDATION.lower():
+            config_manager.append_aggregates(get_aggregate_config(args, config_manager))
+
+        elif not args.primary_keys:
+            raise ValueError(
+                "Expected valid primary keys for custom query row validation, got None."
+            )
+
     config_manager.append_calculated_fields(get_calculated_config(args, config_manager))
 
     if config_manager.validation_type == consts.COLUMN_VALIDATION:
@@ -193,7 +197,6 @@ def build_config_from_args(args, config_manager):
                 config_manager.build_column_configs(grouped_columns)
             )
     elif config_manager.validation_type == consts.ROW_VALIDATION:
-        calc_type = args.hash or args.concat
         if args.comparison_fields is not None:
             comparison_fields = cli_tools.get_arg_list(
                 args.comparison_fields, default_value=[]
@@ -201,31 +204,12 @@ def build_config_from_args(args, config_manager):
             config_manager.append_comparison_fields(
                 config_manager.build_config_comparison_fields(comparison_fields)
             )
-            if calc_type is not None and calc_type != "*":
-                config_manager.append_dependent_aliases(comparison_fields)
 
     if args.primary_keys is not None:
         primary_keys = cli_tools.get_arg_list(args.primary_keys)
         config_manager.append_primary_keys(
             config_manager.build_column_configs(primary_keys)
         )
-        if calc_type is not None and calc_type != "*":
-            config_manager.append_dependent_aliases(primary_keys)
-
-    if config_manager.validation_type == consts.CUSTOM_QUERY:
-        config_manager.append_aggregates(get_aggregate_config(args, config_manager))
-        if args.custom_query_type is not None:
-            config_manager.append_custom_query_type(args.custom_query_type)
-        else:
-            raise ValueError(
-                "Expected custom query type to be given, got empty string."
-            )
-        if args.source_query_file is not None:
-            query_file = cli_tools.get_arg_list(args.source_query_file)
-            config_manager.append_source_query_file(query_file)
-        if args.target_query_file is not None:
-            query_file = cli_tools.get_arg_list(args.target_query_file)
-            config_manager.append_target_query_file(query_file)
 
     return config_manager
 
@@ -279,6 +263,12 @@ def build_config_managers_from_args(args):
     )
 
     is_filesystem = source_client._source_type == "FileSystem"
+
+    if config_type == consts.CUSTOM_QUERY and args.tables_list is not None:
+        args.tables_list = None
+        logging.warning(
+            "tables-list/tbls flag is not supported for custom-query validations, supplied tables list will be ignored."
+        )
     tables_list = cli_tools.get_tables_list(
         args.tables_list, default_value=[{}], is_filesystem=is_filesystem
     )
@@ -309,6 +299,7 @@ def build_config_managers_from_args(args):
             filter_status=filter_status,
             verbose=args.verbose,
         )
+
         if config_type != consts.SCHEMA_VALIDATION:
             config_manager = build_config_from_args(args, config_manager)
         else:
@@ -534,7 +525,6 @@ def validate(args):
 
 
 def main():
-
     # Create Parser and Get Deployment Info
     args = cli_tools.get_parsed_args()
     logging.basicConfig(
@@ -542,7 +532,6 @@ def main():
         format="%(asctime)s-%(levelname)s: %(message)s",
         datefmt="%m/%d/%Y %I:%M:%S %p",
     )
-
     if args.command == "connections":
         run_connections(args)
     elif args.command == "run-config":
