@@ -133,17 +133,6 @@ class ConfigManager(object):
             self.calculated_fields + calculated_configs
         )
 
-    @property
-    def dependent_aliases(self):
-        """Return all columns that are needed in final dataframe for row validations."""
-        return self._config.get(consts.CONFIG_DEPENDENT_ALIASES, [])
-
-    def append_dependent_aliases(self, dependent_aliases):
-        """Appends columns that are needed in final dataframe for row validations."""
-        self._config[consts.CONFIG_DEPENDENT_ALIASES] = (
-            self.dependent_aliases + dependent_aliases
-        )
-
     @property
     def query_groups(self):
         """Return Query Groups from Config"""
@@ -281,6 +270,20 @@ class ConfigManager(object):
         """Return threshold from Config"""
         return self._config.get(consts.CONFIG_THRESHOLD, 0.0)
 
+    @property
+    def source_query(self):
+        return self._config.get(consts.CONFIG_SOURCE_QUERY, None)
+
+    def append_source_query(self, source_query):
+        self._config["source_query"] = source_query
+
+    @property
+    def target_query(self):
+        return self._config.get(consts.CONFIG_TARGET_QUERY, None)
+
+    def append_target_query(self, target_query):
+        self._config["target_query"] = target_query
+
     @property
     def exclusion_columns(self):
         """Return the exclusion columns from Config"""
@@ -305,10 +308,20 @@ class ConfigManager(object):
             )
         return self._source_ibis_table
 
+    def get_source_ibis_table_from_query(self):
+        """Return IbisTable from source."""
+        self._source_ibis_table = clients.get_ibis_query(
+            self.source_client, self.source_query
+        )
+        return self._source_ibis_table
+
     def get_source_ibis_calculated_table(self, depth=None):
         """Return mutated IbisTable from source
         n: Int the depth of subquery requested"""
-        table = self.get_source_ibis_table()
+        if self.validation_type == consts.CUSTOM_QUERY:
+            table = self.get_source_ibis_table_from_query()
+        else:
+            table = self.get_source_ibis_table()
         vb = ValidationBuilder(self)
         calculated_table = table.mutate(
             vb.source_builder.compile_calculated_fields(table, n=depth)
@@ -324,10 +337,20 @@ class ConfigManager(object):
             )
         return self._target_ibis_table
 
+    def get_target_ibis_table_from_query(self):
+        """Return IbisTable from source."""
+        self._target_ibis_table = clients.get_ibis_query(
+            self.target_client, self.target_query
+        )
+        return self._target_ibis_table
+
     def get_target_ibis_calculated_table(self, depth=None):
         """Return mutated IbisTable from target
         n: Int the depth of subquery requested"""
-        table = self.get_target_ibis_table()
+        if self.validation_type == consts.CUSTOM_QUERY:
+            table = self.get_target_ibis_table_from_query()
+        else:
+            table = self.get_target_ibis_table()
         vb = ValidationBuilder(self)
         calculated_table = table.mutate(
             vb.target_builder.compile_calculated_fields(table, n=depth)
@@ -445,8 +468,8 @@ class ConfigManager(object):
         field_configs = []
         for field in fields:
             column_config = {
-                consts.CONFIG_SOURCE_COLUMN: field.casefold(),
-                consts.CONFIG_TARGET_COLUMN: field.casefold(),
+                consts.CONFIG_SOURCE_COLUMN: field,
+                consts.CONFIG_TARGET_COLUMN: field,
                 consts.CONFIG_FIELD_ALIAS: field,
                 consts.CONFIG_CAST: None,
             }
@@ -489,13 +512,13 @@ class ConfigManager(object):
         return aggregate_config
 
     def build_and_append_pre_agg_calc_config(
-        self, column, calc_func, cast_type=None, depth=0
+        self, source_column, target_column, calc_func, cast_type=None, depth=0
     ):
         """Create calculated field config used as a pre-aggregation step. Appends to calulated fields if does not already exist and returns created config."""
         calculated_config = {
-            consts.CONFIG_CALCULATED_SOURCE_COLUMNS: [column],
-            consts.CONFIG_CALCULATED_TARGET_COLUMNS: [column],
-            consts.CONFIG_FIELD_ALIAS: f"{calc_func}__{column}",
+            consts.CONFIG_CALCULATED_SOURCE_COLUMNS: [source_column],
+            consts.CONFIG_CALCULATED_TARGET_COLUMNS: [target_column],
+            consts.CONFIG_FIELD_ALIAS: f"{calc_func}__{source_column}",
             consts.CONFIG_TYPE: calc_func,
             consts.CONFIG_DEPTH: depth,
         }
@@ -504,7 +527,7 @@ class ConfigManager(object):
             calculated_config[consts.CONFIG_DEFAULT_CAST] = cast_type
             calculated_config[
                 consts.CONFIG_FIELD_ALIAS
-            ] = f"{calc_func}_{cast_type}__{column}"
+            ] = f"{calc_func}_{cast_type}__{source_column}"
 
         existing_calc_fields = [
             config[consts.CONFIG_FIELD_ALIAS] for config in self.calculated_fields
@@ -514,7 +537,9 @@ class ConfigManager(object):
             self.append_calculated_fields([calculated_config])
         return calculated_config
 
-    def append_pre_agg_calc_field(self, column, agg_type, column_type):
+    def append_pre_agg_calc_field(
+        self, source_column, target_column, agg_type, column_type
+    ):
         """Append calculated field for length(string) or epoch_seconds(timestamp) for preprocessing before column validation aggregation."""
         depth, cast_type = 0, None
 
@@ -528,9 +553,11 @@ class ConfigManager(object):
                 calc_func = "cast"
                 cast_type = "timestamp"
                 pre_calculated_config = self.build_and_append_pre_agg_calc_config(
-                    column, calc_func, cast_type, depth
+                    source_column, target_column, calc_func, cast_type, depth
                 )
-                column = pre_calculated_config[consts.CONFIG_FIELD_ALIAS]
+                source_column = target_column = pre_calculated_config[
+                    consts.CONFIG_FIELD_ALIAS
+                ]
                 depth = 1
 
             calc_func = "epoch_seconds"
@@ -543,7 +570,7 @@ class ConfigManager(object):
             raise ValueError(f"Unsupported column type: {column_type}")
 
         calculated_config = self.build_and_append_pre_agg_calc_config(
-            column, calc_func, cast_type, depth
+            source_column, target_column, calc_func, cast_type, depth
         )
 
         aggregate_config = {
@@ -566,8 +593,10 @@ class ConfigManager(object):
         casefold_source_columns = {x.casefold(): str(x) for x in source_table.columns}
         casefold_target_columns = {x.casefold(): str(x) for x in target_table.columns}
 
-        if arg_value and supported_types:
-            supported_types.append("string")
+        if arg_value:
+            arg_value = [x.casefold() for x in arg_value]
+            if supported_types:
+                supported_types.append("string")
 
         allowlist_columns = arg_value or casefold_source_columns
         for column in casefold_source_columns:
@@ -603,7 +632,10 @@ class ConfigManager(object):
                 )
             ):
                 aggregate_config = self.append_pre_agg_calc_field(
-                    column, agg_type, column_type
+                    casefold_source_columns[column],
+                    casefold_target_columns[column],
+                    agg_type,
+                    column_type,
                 )
 
             else:
@@ -713,3 +745,21 @@ class ConfigManager(object):
                     column_aliases[name] = i
                     col_names.append(col)
         return col_names
+
+    def get_query_from_file(self, filename):
+        """Return query from input file"""
+        query = ""
+        try:
+            file = open(filename, "r")
+            query = file.read()
+            query = query.rstrip(";\n")
+        except IOError:
+            logging.warning("Cannot read query file: ", filename)
+
+        if not query or query.isspace():
+            raise ValueError(
+                "Expected file with sql query, got empty file or file with white spaces. "
+                f"input file: {filename}"
+            )
+        file.close()
+        return query
